Struct MaterialPort

pub struct MaterialPort {
    name: CapeStringImpl,
    description: CapeStringImpl,
    connected_object: Option<CapeThermoMaterial>,
    is_inlet: bool,
    shared_unit_data: Rc<RefCell<SharedUnitData>>,
    cobia_object_data: MaterialPortCobiaObjectData,
}
The MaterialPort class implements a CAPE-OPEN 1.2 material port.

It connects to a valid CAPE-OPEN 1.2 compliant material object provided by the PME.

Fields

name: CapeStringImpl

The name of the port

description: CapeStringImpl

The description of the port

connected_object: Option<CapeThermoMaterial>

The connected material object, if any

is_inlet: bool

Indicates whether this port is an inlet (true) or an outlet (false)

shared_unit_data: Rc<RefCell<SharedUnitData>>

Shared data for the unit, containing unit-specific information

cobia_object_data: MaterialPortCobiaObjectData

Cobia object data for this object, which contains generated code to provide the native COBIA interfaces

Implementations

Source

impl MaterialPort

fn create_instance( _material_port_boxed_ptr: *mut *mut ICapeInterface, name: CapeStringImpl, description: CapeStringImpl, is_inlet: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> CapeResult

pub(crate) fn create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_inlet: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> T

Create a new instance of the object and return a smart pointer to it

This function panics if the created object does not implement the interface corresponding to the smart pointer to be returned. For a non-panic version, use the try_create() function.

pub(crate) fn try_create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_inlet: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> Result<T, COBIAError>

Create a new instance of the object and return a smart pointer to it

This function returns an error if the created object does not implement the interface corresponding to the smart pointer to be returned.

pub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self

Get a reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

The user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

pub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>( smart_pointer: &mut T, ) -> &mut Self

Get a mutable reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

This function is unsafe because it allows mutable access to the object. Also the user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

Source

impl MaterialPort

pub(crate) fn get_connected_material(&self) -> Option<CapeThermoMaterial>

Get the connected material object, if any.

Returns:
  • The connected material object, or None if the port is not connected to any material object.
pub(crate) fn get_name(&self) -> &CapeStringImpl

Get the name of the port.

Returns:
  • A reference to the name of the port as a CapeStringImpl.