pub struct MaterialPort {
name: CapeStringImpl,
description: CapeStringImpl,
connected_object: Option<CapeThermoMaterial>,
is_inlet: bool,
shared_unit_data: Rc<RefCell<SharedUnitData>>,
cobia_object_data: MaterialPortCobiaObjectData,
}Expand description
The MaterialPort class implements a CAPE-OPEN 1.2 material port.
It connects to a valid CAPE-OPEN 1.2 compliant material object provided by the PME.
Fields
name: CapeStringImplThe name of the port
description: CapeStringImplThe description of the port
connected_object: Option<CapeThermoMaterial>The connected material object, if any
is_inlet: boolIndicates whether this port is an inlet (true) or an outlet (false)
Shared data for the unit, containing unit-specific information
cobia_object_data: MaterialPortCobiaObjectDataCobia object data for this object, which contains generated code to provide the native COBIA interfaces
Implementations
Sourceimpl MaterialPort
impl MaterialPort
fn create_instance( _material_port_boxed_ptr: *mut *mut ICapeInterface, name: CapeStringImpl, description: CapeStringImpl, is_inlet: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> CapeResult
Sourcepub(crate) fn create<T: CapeSmartPointer>(
name: CapeStringImpl,
description: CapeStringImpl,
is_inlet: bool,
shared_unit_data: Rc<RefCell<SharedUnitData>>,
) -> T
pub(crate) fn create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_inlet: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> T
Create a new instance of the object and return a smart pointer to it
This function panics if the created object does not implement the interface corresponding to the smart pointer to be returned. For a non-panic version, use the try_create() function.
Sourcepub(crate) fn try_create<T: CapeSmartPointer>(
name: CapeStringImpl,
description: CapeStringImpl,
is_inlet: bool,
shared_unit_data: Rc<RefCell<SharedUnitData>>,
) -> Result<T, COBIAError>
pub(crate) fn try_create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_inlet: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> Result<T, COBIAError>
Create a new instance of the object and return a smart pointer to it
This function returns an error if the created object does not implement the interface corresponding to the smart pointer to be returned.
Sourcepub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self
pub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self
Get a reference to the object
Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows
Safety
The user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.
Sourcepub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>(
smart_pointer: &mut T,
) -> &mut Self
pub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>( smart_pointer: &mut T, ) -> &mut Self
Get a mutable reference to the object
Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows
Safety
This function is unsafe because it allows mutable access to the object. Also the user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.
Sourceimpl MaterialPort
impl MaterialPort
Sourcepub(crate) fn get_connected_material(&self) -> Option<CapeThermoMaterial>
pub(crate) fn get_connected_material(&self) -> Option<CapeThermoMaterial>
Get the connected material object, if any.
Returns:
- The connected material object, or
Noneif the port is not connected to any material object.